Index: wp-includes/theme.php
===================================================================
--- wp-includes/theme.php	(revision 23179)
+++ wp-includes/theme.php	(working copy)
@@ -84,26 +84,26 @@
  *
  * @since 3.4.0
  *
  * @param string $stylesheet Directory name for the theme. Optional. Defaults to current theme.
  * @param string $theme_root Absolute path of the theme root to look in. Optional. If not specified, get_raw_theme_root()
  * 	is used to calculate the theme root for the $stylesheet provided (or current theme).
  * @return WP_Theme Theme object. Be sure to check the object's exists() method if you need to confirm the theme's existence.
  */
-function wp_get_theme( $stylesheet = null, $theme_root = null ) {
+function wp_get_theme( $theme_dir = null, $theme_root = null ) {
 	global $wp_theme_directories;
 
-	if ( empty( $stylesheet ) )
-		$stylesheet = get_stylesheet();
+	if ( empty( $theme_dir ) )
+		$theme_dir = get_stylesheet();
 
 	if ( empty( $theme_root ) ) {
-		$theme_root = get_raw_theme_root( $stylesheet );
+		$theme_root = get_raw_theme_root( $theme_dir );
 		if ( false === $theme_root )
 			$theme_root = WP_CONTENT_DIR . '/themes';
 		elseif ( ! in_array( $theme_root, (array) $wp_theme_directories ) )
 			$theme_root = WP_CONTENT_DIR . $theme_root;
 	}
 
-	return new WP_Theme( $stylesheet, $theme_root );
+	return new WP_Theme( $theme_dir, $theme_root );
 }
 
 /**
@@ -84,26 +84,26 @@
  * @since 3.4.0
  *
- * @param string $stylesheet Directory name for the theme. Optional. Defaults to current theme.
+ * @param string $theme_dir Directory name for the theme. Optional. Defaults to current theme.
  * @param string $theme_root Absolute path of the theme root to look in. Optional. If not specified, get_raw_theme_root()
@@ -84,26 +84,26 @@
  * @param string $theme_root Absolute path of the theme root to look in. Optional. If not specified, get_raw_theme_root()
- * 	is used to calculate the theme root for the $stylesheet provided (or current theme).
+ * 	is used to calculate the theme root for the $theme_dir provided (or current theme).
  * @return WP_Theme Theme object. Be sure to check the object's exists() method if you need to confirm the theme's existence.
  */
